@@ -29,6 +29,7 @@ __copyright__ = "Copyright (c) 2004-2009 Sun Microsystems Inc." \
                 "Copyright (c) 2012 Igalia, S.L."
 __license__   = "LGPL"
 
+import gi
 import importlib
 import os
 import pyatspi
@@ -49,10 +50,15 @@ try:
     # for this is to allow "orca --text-setup" to work even if
     # the desktop is not running.
     #
+    gi.require_version("Gtk", "3.0")
     from gi.repository import Gtk
+
+    gi.require_version("Gdk", "3.0")
     from gi.repository import Gdk
+
     # Note: This last import is here due to bgo #673396.
     # See bgo#673397 for the rest of the story.
+    gi.require_version("GdkX11", "3.0")
     from gi.repository.GdkX11 import X11Screen
 except:
     pass
@@ -250,6 +256,8 @@ def _processKeyboardEvent(event):
         return False
 
     if isPressedEvent:
+        if not orca_state.activeWindow:
+            orca_state.activeWindow = script.utilities.activeWindow()
         script.presentationInterrupt()
     script.presentKeyboardEvent(keyboardEvent)
     if keyboardEvent.isModifierKey() and not isOrcaModifier:
@@ -429,6 +437,7 @@ def loadUserSettings(script=None, inputEvent=None, skipReloadMessage=False):
         _profile = _settingsManager.getSetting('activeProfile')[1]
         try:
             _userSettings = _settingsManager.getGeneralSettings(_profile)
+            _settingsManager.setProfile(_profile)
             reloaded = True
         except ImportError:
             debug.printException(debug.LEVEL_FINEST)
@@ -689,6 +698,8 @@ def shutdown(script=None, inputEvent=None):
     orca_state.activeScript.presentMessage(messages.STOP_ORCA)
 
     _scriptManager.deactivate()
+
+    _eventManager.deregisterKeystrokeListener(_processKeyboardEvent)
     _eventManager.deactivate()
 
     # Shutdown all the other support.
